bear
Description: the babbling of a coder and cat herder
Keywords: bear,English,USA,Philadelphia,Pennsylvania

## The great way is very level and easy
but people love the by-ways1

My $dayjob is currently running Operations for &yet.

Currently I am also serving on the XSF's 2014 Board.

I'm also working on a personal desktop/dashboard to try and manage the information flow that modern social software has created. This project is named Palala and according to Wikipedia, is derived from Lephalale (Sotho) language and means "one that inundates."

My goal for Palala is to provide a rules-based dashboard where the flow of each persons communications can be prioritized based on status (offline, dnd, available) and connectivity (mobile, desktop, couch.)